@@ -25,7 +25,7 @@ class FeaturesClient(NamespacedClient):
         Gets a list of features which can be included in snapshots using the
         feature_states field when creating a snapshot
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/get-features-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-features-api.html>`_
 
         :arg master_timeout: Explicit operation timeout for connection
             to master node
@@ -33,3 +33,19 @@ class FeaturesClient(NamespacedClient):
         return await self.transport.perform_request(
             "GET", "/_features", params=params, headers=headers
         )
+
+    @query_params()
+    async def reset_features(self, params=None, headers=None):
+        """
+        Resets the internal state of features, usually by deleting system indices
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-snapshots.html>`_
+
+        .. warning::
+
+            This API is **experimental** so may include breaking changes
+            or be removed in a future version
+        """
+        return await self.transport.perform_request(
+            "POST", "/_features/_reset", params=params, headers=headers
+        )
