@@ -24,7 +24,7 @@ class SlmClient(NamespacedClient):
         """
         Deletes an existing snapshot lifecycle policy.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-delete-policy.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-delete-policy.html>`_
 
         :arg policy_id: The id of the snapshot lifecycle policy to
             remove
@@ -45,7 +45,7 @@ class SlmClient(NamespacedClient):
         Immediately creates a snapshot according to the lifecycle policy, without
         waiting for the scheduled time.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-execute-lifecycle.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-execute-lifecycle.html>`_
 
         :arg policy_id: The id of the snapshot lifecycle policy to be
             executed
@@ -66,7 +66,7 @@ class SlmClient(NamespacedClient):
         Deletes any snapshots that are expired according to the policy's retention
         rules.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-execute-retention.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-execute-retention.html>`_
         """
         return await self.transport.perform_request(
             "POST", "/_slm/_execute_retention", params=params, headers=headers
@@ -78,7 +78,7 @@ class SlmClient(NamespacedClient):
         Retrieves one or more snapshot lifecycle policy definitions and information
         about the latest snapshot attempts.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-get-policy.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-get-policy.html>`_
 
         :arg policy_id: Comma-separated list of snapshot lifecycle
             policies to retrieve
@@ -96,7 +96,7 @@ class SlmClient(NamespacedClient):
         Returns global and policy-level statistics about actions taken by snapshot
         lifecycle management.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-get-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-get-stats.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/_slm/stats", params=params, headers=headers
@@ -107,7 +107,7 @@ class SlmClient(NamespacedClient):
         """
         Creates or updates a snapshot lifecycle policy.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-put-policy.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-put-policy.html>`_
 
         :arg policy_id: The id of the snapshot lifecycle policy
         :arg body: The snapshot lifecycle policy definition to register
@@ -128,7 +128,7 @@ class SlmClient(NamespacedClient):
         """
         Retrieves the status of snapshot lifecycle management (SLM).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-get-status.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-get-status.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/_slm/status", params=params, headers=headers
@@ -139,7 +139,7 @@ class SlmClient(NamespacedClient):
         """
         Turns on snapshot lifecycle management (SLM).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-start.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-start.html>`_
         """
         return await self.transport.perform_request(
             "POST", "/_slm/start", params=params, headers=headers
@@ -150,7 +150,7 @@ class SlmClient(NamespacedClient):
         """
         Turns off snapshot lifecycle management (SLM).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/slm-api-stop.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/slm-api-stop.html>`_
         """
         return await self.transport.perform_request(
             "POST", "/_slm/stop", params=params, headers=headers
