@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, query_params
 
 
 class SqlClient(NamespacedClient):
@@ -24,7 +24,7 @@ class SqlClient(NamespacedClient):
         """
         Clears the SQL cursor
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/sql-pagination.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/sql-pagination.html>`_
 
         :arg body: Specify the cursor value in the `cursor` element to
             clean the cursor.
@@ -41,7 +41,7 @@ class SqlClient(NamespacedClient):
         """
         Executes a SQL request
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/sql-rest-overview.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/sql-rest-overview.html>`_
 
         :arg body: Use the `query` element to start a query. Use the
             `cursor` element to continue a query.
@@ -60,7 +60,7 @@ class SqlClient(NamespacedClient):
         """
         Translates SQL into Elasticsearch queries
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/sql-translate.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/sql-translate.html>`_
 
         :arg body: Specify the query in the `query` element.
         """
