@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class ClusterClient(NamespacedClient):
@@ -36,7 +36,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns basic information about the health of the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-health.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-health.html>`_
 
         :arg index: Limit the information returned to a specific index
         :arg expand_wildcards: Whether to expand wildcard expression to
@@ -76,7 +76,7 @@ class ClusterClient(NamespacedClient):
         Returns a list of any cluster-level changes (e.g. create index, update mapping,
         allocate or fail shard) which have not yet been executed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-pending.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-pending.html>`_
 
         :arg local: Return local information, do not retrieve the state
             from master node (default: false)
@@ -100,7 +100,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns a comprehensive information about the state of the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-state.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-state.html>`_
 
         :arg metric: Limit the information returned to the specified
             metrics  Valid choices: _all, blocks, metadata, nodes, routing_table,
@@ -140,7 +140,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns high-level overview of cluster statistics.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-stats.html>`_
 
         :arg node_id: A comma-separated list of node IDs or names to
             limit the returned information; use `_local` to return information from
@@ -166,7 +166,7 @@ class ClusterClient(NamespacedClient):
         """
         Allows to manually change the allocation of individual shards in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-reroute.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-reroute.html>`_
 
         :arg body: The definition of `commands` to perform (`move`,
             `cancel`, `allocate`)
@@ -192,7 +192,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns cluster settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-update-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-get-settings.html>`_
 
         :arg flat_settings: Return settings in flat format (default:
             false)
@@ -211,7 +211,7 @@ class ClusterClient(NamespacedClient):
         """
         Updates the cluster settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-update-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-update-settings.html>`_
 
         :arg body: The settings to be updated. Can be either `transient`
             or `persistent` (survives cluster restart).
@@ -233,7 +233,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns the information about configured remote clusters.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-remote-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-remote-info.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_remote/info", params=params, headers=headers
@@ -244,7 +244,7 @@ class ClusterClient(NamespacedClient):
         """
         Provides explanations for shard allocations in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/cluster-allocation-explain.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/cluster-allocation-explain.html>`_
 
         :arg body: The index, shard, and primary flag to explain. Empty
             means 'explain the first unassigned shard'
@@ -266,12 +266,7 @@ class ClusterClient(NamespacedClient):
         """
         Deletes a component template
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-component-template.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/indices-component-template.html>`_
 
         :arg name: The name of the template
         :arg master_timeout: Specify timeout for connection to master
@@ -292,12 +287,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns one or more component templates
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-component-template.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/indices-component-template.html>`_
 
         :arg name: The comma separated names of the component templates
         :arg local: Return local information, do not retrieve the state
@@ -317,12 +307,7 @@ class ClusterClient(NamespacedClient):
         """
         Creates or updates a component template
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-component-template.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/indices-component-template.html>`_
 
         :arg name: The name of the template
         :arg body: The template definition
@@ -348,12 +333,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns information about whether a particular component template exist
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-component-template.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/indices-component-template.html>`_
 
         :arg name: The name of the template
         :arg local: Return local information, do not retrieve the state
@@ -376,7 +356,7 @@ class ClusterClient(NamespacedClient):
         """
         Clears cluster voting config exclusions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/voting-config-exclusions.html>`_
 
         :arg wait_for_removal: Specifies whether to wait for all
             excluded nodes to be removed from the cluster before clearing the voting
@@ -394,7 +374,7 @@ class ClusterClient(NamespacedClient):
         """
         Updates the cluster voting config exclusions by node ids or node names.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/voting-config-exclusions.html>`_
 
         :arg node_ids: A comma-separated list of the persistent ids of
             the nodes to exclude from the voting configuration. If specified, you
